@@ -1,5 +1,5 @@
 package Net::Hadoop::Oozie::TheJudge;
-$Net::Hadoop::Oozie::TheJudge::VERSION = '0.102';
+$Net::Hadoop::Oozie::TheJudge::VERSION = '0.103';
 use 5.010;
 use strict;
 use warnings;
@@ -142,7 +142,7 @@ sub question {
                 ;
     }
 
-    $out .= sprintf qq{\n\nOozie console:\n\nhttp://%s/?job=%s\n},
+    $out .= sprintf qq{\n\nOozie console:\n\n%s/?job=%s\n},
                         $oozie->oozie_uri,
                         $job_id,
             ;
@@ -171,7 +171,7 @@ Net::Hadoop::Oozie::TheJudge
 
 =head1 VERSION
 
-version 0.102
+version 0.103
 
 =head1 SYNOPSIS
 
